@@ -11,7 +11,7 @@ import numpy as np
 import pandas as pd
 import jpype
 
-from actipy import processing
+from actipy import processing as P
 
 
 __all__ = ['read_device', 'process']
@@ -23,9 +23,9 @@ def read_device(input_file,
                 detect_nonwear=True,
                 resample_hz='uniform',
                 verbose=True):
-    """ 
+    """
     Read and process accelerometer device file. Returns a pandas.DataFrame with
-    the processed data and a dict with processing info. 
+    the processed data and a dict with processing info.
 
     :param input_file: Path to accelerometer file.
     :type input_file: str
@@ -34,7 +34,7 @@ def read_device(input_file,
     :type lowpass_hz: int, optional
     :param calibrate_gravity: Whether to perform gravity calibration. Defaults to True.
     :type calibrate_gravity: bool, optional
-    :param detect_nonwear: Whether to perform non-wear detection. Defaults to True. 
+    :param detect_nonwear: Whether to perform non-wear detection. Defaults to True.
     :type detect_nonwear: bool, optional
     :param resample_hz: Target frequency (Hz) to resample the signal. If
         "uniform", use the implied frequency (use this option to fix any device
@@ -55,9 +55,7 @@ def read_device(input_file,
                                  resample_hz=resample_hz,
                                  verbose=verbose)
 
-    info_misc = processing.misc(data, info_process.get('ResampleRate', info_read['SampleRate']))
-
-    info = {**info_read, **info_misc, **info_process}
+    info = {**info_read, **info_process}
 
     return data, info
 
@@ -68,7 +66,7 @@ def process(data, sample_rate,
             detect_nonwear=True,
             resample_hz='uniform',
             verbose=True):
-    """ 
+    """
     Process a pandas.DataFrame of acceleration time-series. Returns a
     pandas.DataFrame with the processed data and a dict with processing info.
 
@@ -82,7 +80,7 @@ def process(data, sample_rate,
     :type lowpass_hz: int, optional
     :param calibrate_gravity: Whether to perform gravity calibration. Defaults to True.
     :type calibrate_gravity: bool, optional
-    :param detect_nonwear: Whether to perform non-wear detection. Defaults to True. 
+    :param detect_nonwear: Whether to perform non-wear detection. Defaults to True.
     :type detect_nonwear: bool, optional
     :param resample_hz: Target frequency (Hz) to resample the signal. If
         "uniform", use the implied frequency (use this option to fix any device
@@ -100,7 +98,7 @@ def process(data, sample_rate,
 
     if lowpass_hz not in (None, False):
         timer.start("Lowpass filter...")
-        data, info_lowpass = processing.lowpass(data, sample_rate, lowpass_hz)
+        data, info_lowpass = P.lowpass(data, sample_rate, lowpass_hz)
         info.update(info_lowpass)
         timer.stop()
 
@@ -109,27 +107,27 @@ def process(data, sample_rate,
     stationary_indicator = None
     if calibrate_gravity or detect_nonwear:
         timer.start("Getting stationary points...")
-        stationary_indicator = processing.get_stationary_indicator(data)
+        stationary_indicator = P.get_stationary_indicator(data)
         timer.stop()
 
     if calibrate_gravity:
         timer.start("Gravity calibration...")
-        data, info_calib = processing.calibrate_gravity(data, stationary_indicator=stationary_indicator)
+        data, info_calib = P.calibrate_gravity(data, stationary_indicator=stationary_indicator)
         info.update(info_calib)
         timer.stop()
 
     if detect_nonwear:
         timer.start("Nonwear detection...")
-        data, info_nonwear = processing.detect_nonwear(data, stationary_indicator=stationary_indicator)
+        data, info_nonwear = P.detect_nonwear(data, stationary_indicator=stationary_indicator)
         info.update(info_nonwear)
         timer.stop()
 
     if resample_hz not in (None, False):
         timer.start("Resampling...")
         if resample_hz in ('uniform', True):
-            data, info_resample = processing.resample(data, sample_rate)
+            data, info_resample = P.resample(data, sample_rate)
         else:
-            data, info_resample = processing.resample(data, resample_hz)
+            data, info_resample = P.resample(data, resample_hz)
         info.update(info_resample)
         timer.stop()
 
@@ -162,22 +160,31 @@ def _read_device(input_file, verbose=True):
 
         # Device info
         info_device = get_device_info(input_file)
+        info.update(info_device)
 
         # Parsing. Main action happens here.
         timer.start("Reading file...")
-        info_read = java_read_device(input_file, tmpout, verbose)
+        info_java = java_read_device(input_file, tmpout, verbose)
+        info.update(info_java)
         timer.stop()
 
         timer.start("Converting to dataframe...")
         # Load parsed data to a pandas dataframe
-        data = npy2df(np.load(tmpout, mmap_mode='r'))
+        data = P.npy2df(np.load(tmpout, mmap_mode='r+'))
         # Fix if time non-increasing (rarely occurs)
         data, nonincr_time_errs = fix_nonincr_time(data)
         # Update read errors. Non-increasing time errors scaled by sample rate
-        info_read['ReadErrors'] += int(np.ceil(nonincr_time_errs / info_read['SampleRate']))
+        info['ReadErrors'] += int(np.ceil(nonincr_time_errs / info['SampleRate']))
         timer.stop()
 
-        info.update({**info_device, **info_read})
+        # Start/end times, wear time, interrupts
+        t = data.index.to_series()
+        strftime = "%Y-%m-%d %H:%M:%S"
+        info['StartTime'], info['EndTime'] = t[0].strftime(strftime), t[-1].strftime(strftime)
+        info['NumTicks'] = len(data)
+        wear_time, num_interrupts = P.get_wear_time(t)
+        info['WearTime(days)'] = wear_time / (60 * 60 * 24)
+        info['NumInterrupts'] = num_interrupts
 
         return data, info
 
@@ -249,17 +256,6 @@ def decompr(input_file, target_dir):
     return newfile
 
 
-def npy2df(data):
-    """ Convert numpy array to pandas dataframe.
-    Also parse time and set it as index. """
-
-    data = pd.DataFrame(data)
-    data['time'] = data['time'].astype('datetime64[ms]')
-    data = data.set_index('time')
-
-    return data
-
-
 def get_device_info(input_file):
     """ Get serial number of device """
 
